@@ -133,13 +133,15 @@ class Credentials(object):
 
     return last_date
 
-  def _to_dict(self, credentials: oauth.Credentials):
+  def _to_dict(self, credentials: oauth.Credentials) -> Mapping[str, Any]:
     return {'token': credentials.token,
             'refresh_token': credentials.refresh_token,
             'token_uri': credentials.token_uri,
             'client_id': credentials.client_id,
             'client_secret': credentials.client_secret,
-            'scopes': credentials.scopes}
+            'scopes': credentials.scopes,
+            'default_scopes': credentials.default_scopes,
+            'expiry': credentials.expiry.strftime('%Y-%m-%dT%H:%M:%SZ')}
 
   @ property
   def credentials(self) -> oauth.Credentials:
@@ -149,7 +151,7 @@ class Credentials(object):
        (google.oauth2.credentials.Credentials):  the credentials
     """
     expiry = self._to_utc(
-        datetime.now().astimezone(pytz.utc) + relativedelta(minutes=30))
+        datetime.now().astimezone(pytz.utc) + relativedelta(minutes=60))
 
     if token := self.token_details:
       if isinstance(token, str):
