@@ -99,7 +99,7 @@ class SecretManager(AbstractDatastore):
 
     latest = self._get_latest(id)
 
-    # Destroy other versions
+    # Destroy all versions other than the latest for cost reasons..
     request = secretmanager_v1.ListSecretVersionsRequest(
         parent=self.client.secret_path(project=self._project, secret=id),
         filter=f'state:enabled'  # AND name!="{latest.name}"'
@@ -153,7 +153,9 @@ class SecretManager(AbstractDatastore):
     try:
       request = secretmanager_v1.AccessSecretVersionRequest(name=secret)
       response = self.client.access_secret_version(request=request)
-      return json.loads(response.payload.data.decode('utf-8'))
+      document = json.loads(response.payload.data.decode('utf-8'))
+      return document
+
     except Exception as e:
       print(e)
       return None
